@@ -1,3 +1,4 @@
+import asyncio
 import functools
 from typing import Any
 
@@ -34,11 +35,18 @@ class F:
         return F(wrapped)
 
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
-        """ simply call the inner function"""
+        """simply call the inner function"""
         return self.func(*args, **kwargs)
 
     def __repr__(self) -> str:
         return f"<F instance: {repr(self.func)}>"
 
+    @property
+    def is_coroutine_function(self) -> bool:
+        func = self.func
+        while isinstance(func, F):
+            func = func.func
+        return asyncio.iscoroutinefunction(func)
+
 
 FF = F(None)  # type: ignore
